@@ -5,7 +5,7 @@ Editor window module containing :class:`~nodedge.editor_window.EditorWindow` cla
 import json
 import logging
 import os
-from typing import Optional, cast
+from typing import Callable, Optional, Union, cast
 
 from PySide2.QtCore import QPoint, QSettings, QSize, Qt
 from PySide2.QtGui import QClipboard, QCloseEvent, QGuiApplication, QKeySequence
@@ -19,6 +19,7 @@ from PySide2.QtWidgets import (
     QWidget,
 )
 
+from nodedge.application_styler import ApplicationStyler
 from nodedge.editor_widget import EditorWidget
 
 
@@ -46,14 +47,8 @@ class EditorWindow(QMainWindow):
 
         super().__init__(parent)
 
-        # noinspection SpellCheckingInspection
-        logging.basicConfig(
-            format="%(asctime)s|%(levelname).4s|%(filename)10s|"
-            "%(lineno).3s|%(message)s|%(funcName)s"
-        )
-
         self.__logger = logging.getLogger(__file__)
-        self.__logger.setLevel(logging.DEBUG)
+        self.__logger.setLevel(logging.INFO)
 
         self.companyName = "Nodedge"
         self.productName = "Editor"
@@ -61,6 +56,9 @@ class EditorWindow(QMainWindow):
         self.instance: QGuiApplication = cast(
             QGuiApplication, QGuiApplication.instance()
         )
+
+        self.styler = ApplicationStyler()
+
         self.clipboard: QClipboard = self.instance.clipboard()
 
         # Pycharm does not recognise resolve connect method so the inspection is
@@ -140,70 +138,64 @@ class EditorWindow(QMainWindow):
         """
         Create basic `File` and `Edit` actions.
         """
-        self.newAct: QAction = QAction("&New", self)
-        self.newAct.setShortcut(QKeySequence("Ctrl+N"))
-        self.newAct.setStatusTip("Create new Nodedge graph")
-        self.newAct.triggered.connect(self.newFile)
 
-        self.openAct = QAction("&Open", self)
-        self.openAct.setShortcut(QKeySequence("Ctrl+O"))
-        self.openAct.setStatusTip("Open file")
-        self.openAct.triggered.connect(self.openFile)
+        self.newAct = self.createAction(
+            "&New", self.newFile, "Create new Nodedge graph", QKeySequence("Ctrl+N")
+        )
 
-        self.saveAct = QAction("&Save", self)
-        self.saveAct.setShortcut(QKeySequence("Ctrl+S"))
-        self.saveAct.setStatusTip("Save file")
-        self.saveAct.triggered.connect(self.saveFile)
+        self.openAct = self.createAction(
+            "&Open", self.openFile, "Open file", QKeySequence("Ctrl+O")
+        )
 
-        self.saveAsAct = QAction("Save &As", self)
-        self.saveAsAct.setShortcut(QKeySequence("Ctrl+Shift+S"))
-        self.saveAsAct.setStatusTip("Save file as...")
-        self.saveAsAct.triggered.connect(self.saveFileAs)
+        self.saveAct = self.createAction(
+            "&Save", self.saveFile, "Save file", QKeySequence("Ctrl+S")
+        )
 
-        self.quitAct = QAction("&Quit", self)
-        self.quitAct.setShortcut(QKeySequence("Ctrl+Q"))
-        self.quitAct.setStatusTip("Exit application")
-        self.quitAct.triggered.connect(self.quit)
+        self.saveAsAct = self.createAction(
+            "Save &As", self.saveFileAs, "Save file as...", QKeySequence("Ctrl+Shift+S")
+        )
 
-        self.undoAct = QAction("&Undo", self)
-        self.undoAct.setShortcut(QKeySequence("Ctrl+Z"))
-        self.undoAct.setStatusTip("Undo last operation")
-        self.undoAct.triggered.connect(self.undo)
+        self.quitAct = self.createAction(
+            "&Quit", self.quit, "Exit application", QKeySequence("Ctrl+Q")
+        )
 
-        self.redoAct = QAction("&Redo", self)
-        self.redoAct.setShortcut(QKeySequence("Ctrl+Shift+Z"))
-        self.redoAct.setStatusTip("Redo last operation")
-        self.redoAct.triggered.connect(self.redo)
+        self.undoAct = self.createAction(
+            "&Undo", self.undo, "Undo last operation", QKeySequence("Ctrl+Z")
+        )
 
-        self.cutAct = QAction("C&ut", self)
-        self.cutAct.setShortcut(QKeySequence("Ctrl+X"))
-        self.cutAct.setStatusTip("Cut selected items")
-        self.cutAct.triggered.connect(self.cut)
+        self.redoAct = self.createAction(
+            "&Redo", self.redo, "Redo last operation", QKeySequence("Ctrl+Shift+Z")
+        )
 
-        self.copyAct = QAction("&Copy", self)
-        self.copyAct.setShortcut(QKeySequence("Ctrl+C"))
-        self.copyAct.setStatusTip("Copy selected items")
-        self.copyAct.triggered.connect(self.copy)
+        self.cutAct = self.createAction(
+            "C&ut", self.cut, "Cut selected items", QKeySequence("Ctrl+X")
+        )
 
-        self.pasteAct = QAction("&Paste", self)
-        self.pasteAct.setShortcut(QKeySequence.Paste)
-        self.pasteAct.setStatusTip("Paste selected items")
-        self.pasteAct.triggered.connect(self.paste)
+        self.copyAct = self.createAction(
+            "&Copy", self.copy, "Copy selected items", QKeySequence("Ctrl+C")
+        )
 
-        self.deleteAct = QAction("&Delete", self)
-        self.deleteAct.setShortcut(QKeySequence("Del"))
-        self.deleteAct.setStatusTip("Delete selected items")
-        self.deleteAct.triggered.connect(self.delete)
+        self.pasteAct = self.createAction(
+            "&Paste", self.paste, "Paste selected items", QKeySequence.Paste
+        )
 
-        self.fitInViewAct = QAction("Fit in view", self)
-        self.fitInViewAct.setShortcut(QKeySequence(Qt.Key_Space))
-        self.fitInViewAct.setStatusTip("Fit content in view")
-        self.fitInViewAct.triggered.connect(self.onFitInView)
+        self.deleteAct = self.createAction(
+            "&Delete", self.delete, "Delete selected items", QKeySequence("Del")
+        )
 
-        self.generateCodeAct = QAction("Generate code", self)
-        self.generateCodeAct.setShortcut(QKeySequence("Ctrl+G"))
-        self.generateCodeAct.setStatusTip("Generate python code")
-        self.generateCodeAct.triggered.connect(self.onGenerateCode)
+        self.fitInViewAct = self.createAction(
+            "Fit in view",
+            self.onFitInView,
+            "Fit content in view",
+            QKeySequence(Qt.Key_Space),
+        )
+
+        self.generateCodeAct = self.createAction(
+            "Generate code",
+            self.onGenerateCode,
+            "Generate python code",
+            QKeySequence("Ctrl+G"),
+        )
 
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createMenus(self) -> None:
@@ -213,6 +205,12 @@ class EditorWindow(QMainWindow):
         self.createFileMenu()
         self.createEditMenu()
         self.createViewMenu()
+        self.createCoderMenu()
+
+    # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
+    def createCoderMenu(self):
+        self.coderMenu: QMenu = self.menuBar().addMenu("&Coder")
+        self.coderMenu.addAction(self.generateCodeAct)
 
     # noinspection PyArgumentList, PyAttributeOutsideInit, DuplicatedCode
     def createFileMenu(self):
@@ -284,7 +282,7 @@ class EditorWindow(QMainWindow):
 
         :return: ``None``
         """
-        self.__logger.debug(f"Clipboard changed: {self.clipboard.text()}")
+        self.__logger.debug(f"Clipboard changed: '{self.clipboard.text()}'")
 
     def OnScenePosChanged(self, x: float, y: float):
         """
@@ -471,7 +469,7 @@ class EditorWindow(QMainWindow):
         return ""
 
     @staticmethod
-    def getFileDialogFilter():
+    def getFileDialogFilter() -> str:
         """
         Returns ``str`` standard file open/save filter for ``QFileDialog``
 
@@ -490,7 +488,7 @@ class EditorWindow(QMainWindow):
         :rtype: ``bool``
         """
 
-        if not self.currentEditorWidget.isModified:
+        if self.currentEditorWidget is None or not self.currentEditorWidget.isModified:
             return True
 
         res = QMessageBox.warning(
@@ -512,19 +510,17 @@ class EditorWindow(QMainWindow):
         Read the permanent profile settings for this application.
         """
         settings = QSettings(self.companyName, self.productName)
-        pos: QPoint = cast(QPoint, settings.value("pos", QPoint(200, 200)))
-        size: QSize = cast(QSize, settings.value("size", QSize(400, 400)))
+        self.restoreGeometry(settings.value("geometry"))
+        self.restoreState(settings.value("windowState"))
         self.debugMode = settings.value("debug", False)
-        self.move(pos)
-        self.resize(size)
 
     def writeSettings(self):
         """
         Write the permanent profile settings for this application.
         """
         settings = QSettings(self.companyName, self.productName)
-        settings.setValue("pos", self.pos())
-        settings.setValue("size", self.size())
+        settings.setValue("geometry", self.saveGeometry())
+        settings.setValue("windowState", self.saveState())
         settings.setValue("debug", self.debugMode)
 
     def beforeSaveFileAs(
@@ -550,4 +546,39 @@ class EditorWindow(QMainWindow):
 
     def onGenerateCode(self):
         if self.currentEditorWidget is not None:
-            self.currentEditorWidget.graphicsView.graphicsScene.fitInView()
+            self.currentEditorWidget.scene.coder.generateCode()
+
+    def createAction(
+        self,
+        name: str,
+        callback: Callable,
+        statusTip: Optional[str] = None,
+        shortcut: Union[None, str, QKeySequence] = None,
+    ) -> QAction:
+        """
+        Create an action for this window and add it to actions list.
+
+        :param name: action's name
+        :type name: ``str``
+        :param callback: function to be called when the action is triggered
+        :type callback: ``Callable``
+        :param statusTip: Description of the action displayed
+            at the bottom left of the :class:`~nodedge.editor_window.EditorWindow`.
+        :type statusTip: Optional[``str``]
+        :param shortcut: Keyboard shortcut to trigger the action.
+        :type shortcut: ``Optional[str]``
+        :return:
+        """
+        act = QAction(name, self)
+        act.triggered.connect(callback)
+
+        if statusTip is not None:
+            act.setStatusTip(statusTip)
+            act.setToolTip(statusTip)
+
+        if shortcut is not None:
+            act.setShortcut(QKeySequence(shortcut))
+
+        self.addAction(act)
+
+        return act
