@@ -5,13 +5,14 @@ import logging
 import os
 from typing import Any, Callable, List, Optional, cast
 
-from PySide2.QtCore import QSignalMapper, Qt, QTimer, Slot
-from PySide2.QtGui import QCloseEvent, QIcon, QKeySequence
+from pyqtconsole.console import PythonConsole
+from PySide2.QtCore import QSignalMapper, QSize, Qt, QTimer, Slot
+from PySide2.QtGui import QCloseEvent, QIcon, QKeySequence, QMouseEvent
 from PySide2.QtWidgets import (
     QAction,
+    QDialog,
     QDockWidget,
     QFileDialog,
-    QMdiArea,
     QMdiSubWindow,
     QMenu,
     QMessageBox,
@@ -24,7 +25,8 @@ from nodedge.editor_window import EditorWindow
 from nodedge.history_list_widget import HistoryListWidget
 from nodedge.mdi_area import MdiArea
 from nodedge.mdi_widget import MdiWidget
-from nodedge.node_list_widget import NodeListWidget
+from nodedge.node_tree_widget import NodeTreeWidget
+from nodedge.scene_item_detail_widget import SceneItemDetailWidget
 from nodedge.scene_items_table_widget import SceneItemsTableWidget
 from nodedge.utils import loadStyleSheets
 
@@ -79,16 +81,17 @@ class MdiWindow(EditorWindow):
             os.path.join(os.path.dirname(__file__), "resources/nodedge_logo.png")
         )
         self.setWindowIcon(self.icon)
+        self.setMinimumSize(QSize(880, 600))
 
         self.styleSheetFilename = os.path.join(
-            os.path.dirname(__file__), "qss/calculator-dark.qss"
+            os.path.dirname(__file__), "qss/nodedge_style.qss"
         )
         loadStyleSheets(
             # os.path.join(os.path.dirname(__file__), "qss/calculator-dark.qss"),
             self.styleSheetFilename
         )
 
-        # self.setWindowFlag(Qt.FramelessWindowHint)
+        self.setMouseTracking(True)
 
         self.timer = QTimer()
         self.timer.setTimerType(Qt.PreciseTimer)
@@ -97,12 +100,6 @@ class MdiWindow(EditorWindow):
         self.timer.start()
 
         self.mdiArea = MdiArea()
-        self.mdiArea.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
-        self.mdiArea.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
-        self.mdiArea.setViewMode(QMdiArea.TabbedView)
-        self.mdiArea.setDocumentMode(True)
-        self.mdiArea.setTabsClosable(True)
-        self.mdiArea.setTabsMovable(True)
         self.setCentralWidget(self.mdiArea)
 
         self.addCurrentEditorWidgetChangedListener(self.updateMenus)
@@ -112,9 +109,11 @@ class MdiWindow(EditorWindow):
         self.windowMapper = QSignalMapper(self)
         self.windowMapper.mapped[QWidget].connect(self.setActiveSubWindow)
 
+        self.createSceneItemDetailDock()
         self.createNodesDock()
         self.createHistoryDock()
         self.createSceneItemsDock()
+        self.createPythonConsole()
 
         self.createActions()
         self.createMenus()
@@ -130,8 +129,8 @@ class MdiWindow(EditorWindow):
         """
         Create the status bar describing Nodedge status and the mouse position.
         """
-        self.statusBar().showMessage("Ready")
         super().createStatusBar()
+        self.statusBar().showMessage("Ready")
 
     # noinspection PyArgumentList, PyAttributeOutsideInit
     def createActions(self) -> None:
@@ -140,37 +139,43 @@ class MdiWindow(EditorWindow):
         """
         super().createActions()
 
-        self.closeAct = QAction("Cl&ose", self)
-        self.closeAct.setStatusTip("Close the active window")
-        self.closeAct.triggered.connect(self.mdiArea.closeActiveSubWindow)
+        self.closeAct = self.createAction(
+            "Cl&ose", self.mdiArea.closeActiveSubWindow, "Close the active window"
+        )
 
-        self.closeAllAct = QAction("Close &All", self)
-        self.closeAllAct.setStatusTip("Close all the windows")
-        self.closeAllAct.triggered.connect(self.mdiArea.closeAllSubWindows)
+        self.closeAllAct = self.createAction(
+            "Close &All", self.mdiArea.closeAllSubWindows, "Close all the windows"
+        )
 
-        self.tileAct = QAction("&Tile", self)
-        self.tileAct.setStatusTip("Tile the windows")
-        self.tileAct.triggered.connect(self.mdiArea.tileSubWindows)
+        self.tileAct = self.createAction(
+            "&Tile", self.mdiArea.tileSubWindows, "Tile the windows"
+        )
 
-        self.cascadeAct = QAction("&Cascade", self)
-        self.cascadeAct.setStatusTip("Cascade the windows")
-        self.cascadeAct.triggered.connect(self.mdiArea.cascadeSubWindows)
+        self.cascadeAct = self.createAction(
+            "&Cascade", self.mdiArea.cascadeSubWindows, "Cascade the windows"
+        )
 
-        self.nextAct = QAction("Ne&xt", self)
-        self.nextAct.setShortcut(QKeySequence.NextChild)
-        self.nextAct.setStatusTip("Move the focus to the next window")
-        self.nextAct.triggered.connect(self.mdiArea.activateNextSubWindow)
+        self.nextAct = self.createAction(
+            "Ne&xt",
+            self.mdiArea.activateNextSubWindow,
+            "Move the focus to the next window",
+            QKeySequence.NextChild,
+        )
 
         # noinspection SpellCheckingInspection
-        self.previousAct = QAction("Pre&vious", self)
-        self.previousAct.setShortcut(QKeySequence.PreviousChild)
-        self.previousAct.setStatusTip("Move the focus to the previous window")
-        self.previousAct.triggered.connect(self.mdiArea.activatePreviousSubWindow)
+        self.previousAct = self.createAction(
+            "Pre&vious",
+            self.mdiArea.activatePreviousSubWindow,
+            "Move the focus to the previous window",
+            QKeySequence.PreviousChild,
+        )
 
-        self.nodeToolbarAct = QAction("&Node toolbar", self)
-        self.nodeToolbarAct.setShortcut(QKeySequence("ctrl+alt+n"))
-        self.nodeToolbarAct.setStatusTip("Enable/Disable the node toolbar")
-        self.nodeToolbarAct.triggered.connect(self.onNodesToolbarTriggered)
+        self.nodeToolbarAct = self.createAction(
+            "&Node toolbar",
+            self.onNodesToolbarTriggered,
+            "Enable/Disable the node toolbar",
+            QKeySequence("ctrl+alt+n"),
+        )
 
         self.nodeToolbarAct.setCheckable(True)
         self.nodeToolbarAct.setChecked(True)  # self.nodesDock.isVisible()
@@ -178,14 +183,23 @@ class MdiWindow(EditorWindow):
         self.separatorAct = QAction(self)
         self.separatorAct.setSeparator(True)
 
-        self.aboutAct: QAction = QAction("&About", self)
-        self.aboutAct.setStatusTip("Show the application's About box")
-        self.aboutAct.triggered.connect(self.about)
+        self.aboutAct = self.createAction(
+            "&About", self.about, "Show the application's About box"
+        )
 
-        self.debugAct = QAction("&Debug", self)
-        self.debugAct.setShortcut(QKeySequence("ctrl+alt+shift+d"))
-        self.debugAct.setStatusTip("Enable/Disable the debug mode")
-        self.debugAct.triggered.connect(self.onDebugSwitched)
+        self.debugAct = self.createAction(
+            "&Debug",
+            self.onDebugSwitched,
+            "Enable/Disable the debug mode",
+            QKeySequence("ctrl+alt+shift+d"),
+        )
+
+        self.showDialogActionsAct = self.createAction(
+            "Show dialog actions",
+            self.onShowDialogActions,
+            "Show available actions",
+            QKeySequence("ctrl+shift+a"),
+        )
 
     # noinspection PyAttributeOutsideInit
     def createToolBars(self) -> None:
@@ -205,6 +219,9 @@ class MdiWindow(EditorWindow):
         self.editToolBar.addAction(self.copyAct)
         self.editToolBar.addAction(self.pasteAct)
 
+        self.coderToolbar = self.addToolBar("Coder")
+        self.coderToolbar.addAction(self.generateCodeAct)
+
     def createMenus(self) -> None:
         """
         Create `Window` and `Help` menus.
@@ -353,7 +370,10 @@ class MdiWindow(EditorWindow):
         Create a new sub window containing a
         :class:`~nodedge.editor_widget.EditorWidget`
         """
-        editor = childWidget if childWidget is not None else MdiWidget()
+        editor: MdiWidget = childWidget if childWidget is not None else MdiWidget()
+        editor.scene.coder.notConnectedSocket.connect(  # type: ignore
+            self.onSceneCoderOutputSocketDisconnect
+        )
         subWindow = self.mdiArea.addSubWindow(editor)
 
         icon = QIcon(".")
@@ -363,6 +383,7 @@ class MdiWindow(EditorWindow):
         editor.scene.history.addHistoryModifiedListener(
             self.sceneItemsTableWidget.update
         )
+        editor.scene.addItemSelectedListener(self.sceneItemDetailsWidget.update)
         editor.addCloseEventListener(self.onSubWindowClosed)
 
         return subWindow
@@ -413,18 +434,31 @@ class MdiWindow(EditorWindow):
         if window:
             self.mdiArea.setActiveSubWindow(window)
 
+    # noinspection PyAttributeOutsideInit
+    def createSceneItemDetailDock(self) -> None:
+        """
+        Create Item detail dock.
+        """
+        self.sceneItemDetailsWidget = SceneItemDetailWidget(self)
+
+        self.sceneItemDetailsDock = QDockWidget("Item details")
+        self.sceneItemDetailsDock.setWidget(self.sceneItemDetailsWidget)
+        self.sceneItemDetailsDock.setFloating(False)
+
+        self.addDockWidget(Qt.RightDockWidgetArea, self.sceneItemDetailsDock)
+
     # noinspection PyAttributeOutsideInit
     def createNodesDock(self) -> None:
         """
         Create Nodes dock.
         """
-        self.nodesListWidget = NodeListWidget()
-        self.nodesListWidget.itemsPressed.connect(  # type: ignore
+        self.nodesTreeWidget = NodeTreeWidget()
+        self.nodesTreeWidget.itemsPressed.connect(  # type: ignore
             self.showItemsInStatusBar
         )
 
         self.nodesDock = QDockWidget("Nodes")
-        self.nodesDock.setWidget(self.nodesListWidget)
+        self.nodesDock.setWidget(self.nodesTreeWidget)
         self.nodesDock.setFloating(False)
 
         self.addDockWidget(Qt.RightDockWidgetArea, self.nodesDock)
@@ -463,6 +497,21 @@ class MdiWindow(EditorWindow):
 
         self.addDockWidget(Qt.LeftDockWidgetArea, self.sceneItemsDock)
 
+    # noinspection PyAttributeOutsideInit
+    def createPythonConsole(self) -> None:
+        """
+        Create a python console embedded in a dock.
+        :return: ``None``
+        """
+        self.pythonConsoleWidget = PythonConsole(formats=self.styler.consoleStyle)
+        self.pythonConsoleWidget.eval_in_thread()
+
+        self.pythonConsoleDock = QDockWidget("Python console")
+        self.pythonConsoleDock.setWidget(self.pythonConsoleWidget)
+        self.pythonConsoleDock.setFloating(False)
+
+        self.addDockWidget(Qt.LeftDockWidgetArea, self.pythonConsoleDock)
+
     def closeEvent(self, event: QCloseEvent) -> None:
         """
         Qt's close event handle.
@@ -476,6 +525,7 @@ class MdiWindow(EditorWindow):
             event.ignore()
         else:
             self.writeSettings()
+            self.pythonConsoleWidget.close()
             event.accept()
 
     def newFile(self) -> QMdiSubWindow:
@@ -590,9 +640,6 @@ class MdiWindow(EditorWindow):
             graphicsScene.itemsPressed.connect(  # type: ignore
                 self.showItemsInStatusBar
             )
-            # self.currentEditorWidget.scene.graphicsScene.itemSelected.connect(
-            #     self.sceneItemsTableWidget.onSceneItemSelected
-            # )
 
     def checkStylesheet(self) -> None:
         """
@@ -622,3 +669,28 @@ class MdiWindow(EditorWindow):
     def onDebugSwitched(self):
         """Event called when the debug action is triggered."""
         pass
+
+    @Slot()  # type: ignore
+    def onShowDialogActions(self):
+        self.__logger.info("")
+        dialog = QDialog()
+        dialog.show()
+
+    def mouseMoveEvent(self, event: QMouseEvent):
+        pos = event.pos()
+        self.statusMousePos.setText(f"[{pos.x()}, {pos.y()}]")
+
+        super().mouseMoveEvent(event)
+
+    @Slot()  # type: ignore
+    def onSceneCoderOutputSocketDisconnect(self) -> None:
+        """
+        Callback to deal with :class:`~nodedge.scene_coder.SceneCoder` warning.
+        :return: ``None``
+        """
+        msg = QMessageBox()
+        msg.setIcon(QMessageBox.Warning)
+        msg.setInformativeText("One or more blocks are not connected.")
+        msg.setWindowTitle("Coder warning")
+        msg.setStandardButtons(QMessageBox.Ok)
+        msg.exec_()
