@@ -11,11 +11,12 @@ from typing import Callable, Collection, List, Optional, Tuple, TypeVar, cast
 from PySide2.QtCore import QPoint, QPointF
 from PySide2.QtWidgets import QGraphicsSceneMouseEvent
 
+from nodedge.connector import Socket, SocketLocation
 from nodedge.edge import Edge
 from nodedge.graphics_node import GraphicsNode
 from nodedge.graphics_node_content import GraphicsNodeContent
 from nodedge.serializable import Serializable
-from nodedge.socket import Socket, SocketLocation
+from nodedge.socket_type import SocketType
 from nodedge.utils import dumpException
 
 Pos = TypeVar("Pos", List, Tuple, QPoint, QPointF)
@@ -47,8 +48,8 @@ class Node(Serializable):
         self,
         scene: "Scene",  # type: ignore
         title: str = "Undefined node",
-        inputSocketTypes: Collection[int] = (),
-        outputSocketTypes: Collection[int] = (),
+        inputSocketTypes: Collection[SocketType] = (),
+        outputSocketTypes: Collection[SocketType] = (),
     ):
         """
         :param scene: reference to the :class:`~nodedge.scene.Scene`
@@ -56,14 +57,16 @@ class Node(Serializable):
         :param title: node title shown in scene
         :type title: ``str``
         :param inputSocketTypes: list of types of the input `Sockets`
-        :type inputSocketTypes: ``Collection[int]``
+        :type inputSocketTypes: ``Collection[SocketType]``
         :param outputSocketTypes: list of types of the output `Sockets`
-        :type outputSocketTypes: ``Collection[int]``
+        :type outputSocketTypes: ``Collection[SocketType]``
         """
 
         super().__init__()
         self._title: str = title
         self.scene: "Scene" = scene  # type: ignore
+        self.inputSocketTypes: Collection[SocketType] = inputSocketTypes
+        self.outputSocketTypes: Collection[SocketType] = outputSocketTypes
 
         self.__logger = logging.getLogger(__file__)
         self.__logger.setLevel(logging.INFO)
@@ -106,7 +109,7 @@ class Node(Serializable):
         self.title: str = self._title
         self._socketSpacing: int = 22
         self._inputSocketPosition: SocketLocation = SocketLocation.LEFT_TOP
-        self._outputSocketPosition: SocketLocation = SocketLocation.RIGHT_BOTTOM
+        self._outputSocketPosition: SocketLocation = SocketLocation.RIGHT_TOP
         self._inputAllowMultiEdges: bool = False
         self._outputAllowMultiEdges: bool = True
         self.socketOffsets = {
@@ -119,7 +122,10 @@ class Node(Serializable):
         }
 
     def initSockets(
-        self, inputs: Collection[int], outputs: Collection[int], reset: bool = True
+        self,
+        inputs: Collection[SocketType],
+        outputs: Collection[SocketType],
+        reset: bool = True,
     ) -> None:
         """
         Create input and output sockets.
@@ -197,9 +203,22 @@ class Node(Serializable):
         return self._title
 
     @title.setter
-    def title(self, value: str) -> None:
-        self._title = value
-        self.graphicsNode.title = value
+    def title(self, newTitle: str) -> None:
+        otherNodes = self.scene.nodes.copy()
+        if self in self.scene.nodes:
+            otherNodes.remove(self)
+        alreadyExistingNames = [node.title for node in otherNodes]
+
+        while newTitle in alreadyExistingNames:
+            if newTitle[-1].isnumeric():
+                newLastCharacter = str(int(newTitle[-1]) + 1)
+                newTitle = newTitle[:-1]
+                newTitle += newLastCharacter
+            else:
+                newTitle += "1"
+
+        self._title = newTitle
+        self.graphicsNode.title = newTitle
 
     @property
     def pos(self):
@@ -393,7 +412,7 @@ class Node(Serializable):
             ``False`` to un-dirty them.
         :type newValue: ``bool``
         """
-        for otherNode in self.getChildrenNodes():
+        for otherNode in self.getChildNodes():
             otherNode.isDirty = newValue
 
     def markDescendantsDirty(self, newValue: bool = True) -> None:
@@ -405,7 +424,7 @@ class Node(Serializable):
             ``False`` to un-dirty them.
         :type newValue: ``bool``
         """
-        for otherNode in self.getChildrenNodes():
+        for otherNode in self.getChildNodes():
             otherNode.isDirty = newValue
             otherNode.markChildrenDirty(newValue)
 
@@ -425,7 +444,7 @@ class Node(Serializable):
             them valid.
         :type newValue: ``bool``
         """
-        for otherNode in self.getChildrenNodes():
+        for otherNode in self.getChildNodes():
             otherNode.isInvalid = newValue
 
     def markDescendantsInvalid(self, newValue: bool = True) -> None:
@@ -438,7 +457,7 @@ class Node(Serializable):
         :type newValue: ``bool``
         """
 
-        for otherNode in self.getChildrenNodes():
+        for otherNode in self.getChildNodes():
             otherNode.isInvalid = newValue
             otherNode.markChildrenInvalid(newValue)
 
@@ -456,24 +475,52 @@ class Node(Serializable):
         """
         Evaluate children of this node
         """
-        for node in self.getChildrenNodes():
+        for node in self.getChildNodes():
             # TODO: Investigate if we want to evaluate all the children of the child
             node.eval()
 
-    def getChildrenNodes(self) -> List["Node"]:
+    def getChildNodes(self) -> List["Node"]:
         """
         Retrieve all children connected to this node outputs.
 
         :return: list of `Nodes` connected to this node from all outputs
         :rtype: List[:class:`~nodedge.node.Node`]
         """
-        if not self.outputSockets:
+        return self._getRelativeNodes("child")
+
+    def getParentNodes(self) -> List["Node"]:
+        """
+        Retrieve all parents connected to this node inputs.
+
+        :return: list of `Nodes` connected to this node from all inputs
+        :rtype: List[:class:`~nodedge.node.Node`]
+        """
+        return self._getRelativeNodes("parent")
+
+    def _getRelativeNodes(self, relationship: str) -> List["Node"]:
+        """
+        Protected method to get relative nodes.
+
+        :param relationship: "child" or "parent"
+        :type relationship: str
+        :return: relative nodes
+        :rtype: List[:class:`~nodedge.node.Node`]
+        """
+        if relationship == "child":
+            socketList: List[Socket] = self.outputSockets
+        elif relationship == "parent":
+            socketList = self.inputSockets
+        else:
+            raise NotImplementedError
+
+        if not socketList:
+            self.__logger.debug("Socket list is empty")
             return []
 
-        otherNodes = []
-        for outputSocket in self.outputSockets:
-            for edge in outputSocket.edges:
-                otherNode = edge.getOtherSocket(outputSocket).node
+        otherNodes: List["Node"] = []
+        for socket in socketList:
+            for edge in socket.edges:
+                otherNode = edge.getOtherSocket(socket).node
                 otherNodes.append(otherNode)
 
         return otherNodes
@@ -635,6 +682,7 @@ class Node(Serializable):
                 for socket in self.inputSockets:
                     if socket.index == socketData["index"]:
                         found = socket
+                        found.socketType = SocketType(socketData["socketType"])
                         break
                 if found is None:
                     self.__logger.debug(
@@ -649,7 +697,7 @@ class Node(Serializable):
                         node=self,
                         index=socketData["index"],
                         location=socketData["location"],
-                        socketType=socketData["socketType"],
+                        socketType=SocketType(socketData["socketType"]),
                         countOnThisNodeSide=numberOfInputs,
                         isInput=True,
                     )
@@ -678,6 +726,7 @@ class Node(Serializable):
                     # print("\t", socket, socket.index, "=?", socket_data['index'])
                     if socket.index == socketData["index"]:
                         found = socket
+                        found.socketType = SocketType(socketData["socketType"])
                         break
                 if found is None:
                     self.__logger.debug(
@@ -690,7 +739,7 @@ class Node(Serializable):
                         node=self,
                         index=socketData["index"],
                         location=socketData["location"],
-                        socketType=socketData["socketType"],
+                        socketType=SocketType(socketData["socketType"]),
                         countOnThisNodeSide=numberOfOutputs,
                         isInput=False,
                     )
