@@ -12,12 +12,13 @@ from typing import Callable, List, Optional, cast
 from PySide2.QtGui import QDragEnterEvent, QDropEvent
 from PySide2.QtWidgets import QGraphicsItem
 
-from nodedge.code_generator import CodeGenerator
 from nodedge.edge import Edge
+from nodedge.graphics_node import GraphicsNode
 from nodedge.graphics_scene import GraphicsScene
 from nodedge.graphics_view import GraphicsView
 from nodedge.node import Node
 from nodedge.scene_clipboard import SceneClipboard
+from nodedge.scene_coder import SceneCoder
 from nodedge.scene_history import SceneHistory
 from nodedge.serializable import Serializable
 from nodedge.utils import dumpException
@@ -50,7 +51,7 @@ class Scene(Serializable):
 
         self.history: SceneHistory = SceneHistory(self)
         self.clipboard: SceneClipboard = SceneClipboard(self)
-        self.codeGenerator: CodeGenerator = CodeGenerator(self)
+        self.coder: SceneCoder = SceneCoder(scene=self)
 
         self._isModified: bool = False
         self.isModified: bool = False
@@ -124,6 +125,19 @@ class Scene(Serializable):
 
         return self.graphicsScene.selectedItems()
 
+    @property
+    def selectedNode(self) -> Optional[Node]:
+        ret = None
+        if len(self.selectedItems) == 1:
+            if isinstance(self.selectedItems[0], GraphicsNode):
+                ret = self.selectedItems[0].node
+
+        return ret
+
+    @property
+    def selectedNodes(self) -> List[Node]:
+        return [item for item in self.selectedItems if isinstance(item, GraphicsNode)]
+
     @property
     def graphicsView(self) -> GraphicsView:
         """Shortcut for returning `Scene` ``QGraphicsView``
@@ -135,7 +149,7 @@ class Scene(Serializable):
 
     @property
     def silentSelectionEvents(self):
-        """"
+        """ "
         If this property is true, do not trigger onItemSelected when an item is selected
 
         :return: True is onItemSelected is not triggered when an item is selected
@@ -300,7 +314,7 @@ class Scene(Serializable):
 
     def clear(self) -> None:
         """Remove all `Nodes` from this `Scene`. This causes also to remove all
-        `Edges` """
+        `Edges`"""
         while len(self.nodes) > 0:
             self.nodes[0].remove()
 
